#
# spec file for package xbindkeys
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Guile support is disabled by default, has no real
# advantages except being able to write xbindkeys
# configuration in a lisp-alike syntax but it pulls
# in guile, which is rarely used by most end-users.
#
# To enable guile support, build the spec file and
# pass --with guile to rpmbuild.
%bcond_with guile
Name:           xbindkeys
Version:        1.8.7
Release:        1.9
Summary:        Events Grabbing Program for X-Window
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            https://www.nongnu.org/xbindkeys/
Source:         https://www.nongnu.org/%{name}/%{name}-%{version}.tar.gz
Requires:       tk
%if %{with guile}
BuildRequires:  guile-devel
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  pkgconfig(x11)
%else
BuildRequires:  xorg-x11-devel
%endif

%description
xbindkeys is a program that associates keys or mouse buttons to shell commands
under X. After a little configuration, it can start many commands with the
keyboard (e.g. control+alt+x starts an xterm) or with the mouse buttons.

%if !%{with guile}
guile support is disabled in this package.
To enable guile support, rebuild the src.rpm and pass --with guile
to rpmbuild.
%endif

%prep
%setup -q

%build
%configure \
%if %{with guile}
    --enable-guile
%else
    --disable-guile
%endif

%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS BUGS ChangeLog README TODO xbindkeysrc
%if %{with guile}
%doc xbindkeysrc-combo.scm xbindkeysrc.scm
%endif
%{_bindir}/%{name}
%{_bindir}/%{name}_show
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}_show.1%{?ext_man}

%changelog
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.8.7:
  * Bugfix: Prevent scheme functions to be garbage collected
* Wed Nov 12 2014 nemysis@gmx.ch
- Use %%{name} instead of xbindkeys
- Remove %%doc from Man Pages
* Mon Oct 13 2014 seanpwatson@live.com
- Fixed error with +%%if %%{?with_guile:1}0
* Sun Feb 16 2014 asterios.dramis@gmail.com
- Update to 1.8.6:
  * Bugfix: Do not grab keysym not mapped on keyboard. Prevent a AnyKey grab.
- Removed gcc, make, glibc-devel, autoconf, automake, and libtool build
  requirements (not needed).
- Replaced xorg-x11-devel build requirement with pkgconfig(x11) for
  openSUSE > 11.1.
- Compile the package with support for tk (added tk as runtime requirement).
* Mon Mar 14 2011 pascal.bleser@opensuse.org
- update to 1.8.5:
  * adds Guile 2.0 support
  * replaces some deprecated functions
* Tue Dec  7 2010 pascal.bleser@opensuse.org
- update to 1.8.4:
  * fixes a memory fault when using it with libX11-1.4.0
* Sun Jan 25 2009 guru@unixtech.be
- update to 1.8.3:
  * a listen loop was added in the main loop. This fixes a bug where, in the
    previous version, a keypress was needed to reload the configuration file
    after a keybinding change. Now one can edit the configuration file and
    keybindings are automatically updated after each save.
* Fri Oct  5 2007 guru@unixtech.be
- moved to openSUSE Build Service
